//@line 36 "/builds/tinderbox/Fx-Mozilla1.9-Release/Linux_2.6.9-42.ELsmp_Depend/mozilla/browser/locales/en-US/firefox-l10n.js"

//@line 38 "/builds/tinderbox/Fx-Mozilla1.9-Release/Linux_2.6.9-42.ELsmp_Depend/mozilla/browser/locales/en-US/firefox-l10n.js"

pref("general.useragent.locale", "en-US");
